const config = require('config')
const { services } = require('pubsweet-component-helper-service')

const { getEmailCopy } = require('./emailCopy')

const confirmSignUp = config.get('confirm-signup.url')
const { name: journalName, staffEmail } = config.get('journal')

module.exports = {
  sendNewUserEmail: ({ email, role }) => {
    email.content.subject = 'Confirm your account'

    let emailType
    if (role === 'Handling Editor') {
      emailType = 'he-added-by-admin'
      email.fromEmail = `${journalName} <${staffEmail}>`
    } else {
      emailType = 'user-added-by-admin'
    }

    const { html, text } = email.getNotificationBody({
      emailBodyProps: getEmailCopy({
        role,
        emailType,
      }),
    })

    email.sendEmail({ html, text })
  },
  sendSignupEmail: ({ email, baseUrl, user }) => {
    email.content.subject = 'Confirm your email address'
    email.content.ctaLink = services.createUrl(baseUrl, confirmSignUp, {
      userId: user.id,
      confirmationToken: user.accessTokens.confirmation,
    })

    const { html, text } = email.getNotificationBody({
      emailBodyProps: getEmailCopy({
        emailType: 'user-signup',
      }),
    })

    email.sendEmail({ html, text })
  },
}
